# SPDX-FileCopyrightText: 2023-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv224.system.aggregates import GmpGetAggregatesTestMixin
from ...gmpv225 import GMPTestCase


class Gmpv225GetAggregatesTestCase(GmpGetAggregatesTestMixin, GMPTestCase):
    pass
